@@ -934,8 +934,11 @@ class DKIM(DomainSigner):
   #: @return: True if signature verifies or False otherwise
   #: @raise DKIMException: when the message, signature, or key are badly formed
   def verify(self,idx=0,dnsfunc=get_txt):
-    sig, include_headers, sigheaders = self.verify_headerprep(idx)
-    return self.verify_sig(sig, include_headers, sigheaders[idx], dnsfunc)
+    prep = self.verify_headerprep(idx)
+    if prep:
+        sig, include_headers, sigheaders = prep
+        return self.verify_sig(sig, include_headers, sigheaders[idx], dnsfunc)
+    return False # No signature
 
 
 #: Hold messages and options during ARC signing and verification.
@@ -993,7 +996,7 @@ class ARC(DomainSigner):
   #: @param selector: the DKIM selector value for the signature
   #: @param domain: the DKIM domain value for the signature
   #: @param privkey: a PKCS#1 private key in base64-encoded text form
-  #: @param srv_id: an srv_id for identitfying AR headers to sign & extract cv from
+  #: @param srv_id: a srv_id for identifying AR headers to sign & extract cv from
   #: @param include_headers: a list of strings indicating which headers
   #: are to be signed (default rfc4871 recommended headers)
   #: @return: list of ARC set header fields
